.. currentmodule:: sardana.pool.poolexception

:mod:`~sardana.pool.poolexception`
=======================================

.. automodule:: sardana.pool.poolexception

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :exc:`PoolException`
    * :exc:`UnknownController`
    * :exc:`UnknownControllerLibrary`


PoolException
---------------

.. inheritance-diagram:: PoolException
    :parts: 1
    
.. autoexception:: PoolException
    :inherited-members:
    :members:
    :undoc-members:

UnknownController
--------------------

.. inheritance-diagram:: UnknownController
    :parts: 1
    
.. autoexception:: UnknownController
    :inherited-members:
    :members:
    :undoc-members:

UnknownControllerLibrary
-------------------------

.. inheritance-diagram:: UnknownControllerLibrary
    :parts: 1
    
.. autoexception:: UnknownControllerLibrary
    :inherited-members:
    :members:
    :undoc-members:

